pub fn trust_path() -> Result<PathBuf, ConfigError>Expand description
~/.rpi/agent/trust.json (per-cwd project trust decisions — read-only
parity with pi; rpi does not gate resources behind trust in v1).
pub fn trust_path() -> Result<PathBuf, ConfigError>~/.rpi/agent/trust.json (per-cwd project trust decisions — read-only
parity with pi; rpi does not gate resources behind trust in v1).