pub fn write_auth(store: &AuthStore) -> Result<(), ConfigError>Expand description
Atomically write the whole auth store (ensures the dir exists, writes a
temp sibling, renames over the target, then chmod 0o600 on Unix).
pub fn write_auth(store: &AuthStore) -> Result<(), ConfigError>Atomically write the whole auth store (ensures the dir exists, writes a
temp sibling, renames over the target, then chmod 0o600 on Unix).