pub fn assistant_text(msg: &AssistantMessage) -> StringExpand description
Extract the concatenated text content from an assistant message. Mirrors the
TS print-mode loop (for content of assistantMsg.content if type===text).
pub fn assistant_text(msg: &AssistantMessage) -> StringExtract the concatenated text content from an assistant message. Mirrors the
TS print-mode loop (for content of assistantMsg.content if type===text).