pub fn project_skill_dirs(cwd: &Path) -> Vec<PathBuf>Expand description
Project-only skill directories, excluding user/global configuration. This
is used by rpi dev-local so the current extension can be debugged with
the skills in the current checkout without importing unrelated skills.