pub async fn check_rpi_startup() -> UpdateReportExpand description
Check only the rpi release. Callers can render this report independently so slow package-manager subprocesses never delay the self-update notice.
pub async fn check_rpi_startup() -> UpdateReportCheck only the rpi release. Callers can render this report independently so slow package-manager subprocesses never delay the self-update notice.