project_skill_dirs

Function project_skill_dirs 

pub fn project_skill_dirs(cwd: &Path) -> Vec<PathBuf>
Project-only skill directories, excluding user/global configuration. This is used by rpi dev-local so the current extension can be debugged with the skills in the current checkout without importing unrelated skills.